On 10/09/2014 11:01 AM, Lukas Slebodnik wrote:
ehlo,
The simple patch is attached. The side effect of this patch is reduction time spent in the scan-make-tests from 9 minutes to 4 minutes.
ACK
It looks fine, but I haven't tested it. It would be nice to have a link to CI test results to go with the patch.
Can we work towards fixing the test frameworks so Clang understands what's going on?
Nick